@@ -304,6 +304,7 @@ mate_bg_load_from_system_gsettings (MateBG    *bg,
 				    GSettings *settings,
 				    gboolean   reset_apply)
 {
+	GSettingsSchema *schema;
 	gchar **keys;
 	gchar **k;
 
@@ -312,9 +313,12 @@ mate_bg_load_from_system_gsettings (MateBG    *bg,
 
 	g_settings_delay (settings);
 
-	keys = g_settings_list_keys (settings);
-		for (k = keys; *k; k++) {
-			g_settings_reset (settings, *k);
+	g_object_get (settings, "settings-schema", &schema, NULL);
+	keys = g_settings_schema_list_keys (schema);
+	g_settings_schema_unref (schema);
+
+	for (k = keys; *k; k++) {
+		g_settings_reset (settings, *k);
 	}
 	g_strfreev (keys);
 
@@ -1129,7 +1133,7 @@ mate_bg_get_pixmap_size (MateBG   *bg,
  * @height:
  * @root:
  *
- * Create a surface that can be set as background for @window. If @is_root is
+ * Create a surface that can be set as background for @window. If @root is
  * TRUE, the surface created will be created by a temporary X server connection
  * so that if someone calls XKillClient on it, it won't affect the application
  * who created it.
@@ -1150,7 +1154,7 @@ mate_bg_create_surface (MateBG      *bg,
 }
 
 /**
- * mate_bg_create_surface:
+ * mate_bg_create_surface_scale:
  * @bg: MateBG
  * @window:
  * @width:
@@ -1158,7 +1162,7 @@ mate_bg_create_surface (MateBG      *bg,
  * @scale:
  * @root:
  *
- * Create a scaled surface that can be set as background for @window. If @is_root is
+ * Create a scaled surface that can be set as background for @window. If @root is
  * TRUE, the surface created will be created by a temporary X server connection
  * so that if someone calls XKillClient on it, it won't affect the application
  * who created it.
